// One-time-shot tester 
// for the signaling less-than-or-equal comparison
// between a binary64 and a decimal64
// 
// Copyright (C) 2012, 2013 by
// 
// Laboratoire de l'Informatique du Parallelisme,
// UMR CNRS - ENS Lyon - UCB Lyon 1 - INRIA 5668
// 
// and by
// 
// Laboratoire d'Informatique de Paris 6, equipe PEQUAN,
// UPMC Universite Paris 06 - CNRS - UMR 7606 - LIP6, Paris, France.
// 
// Authors : Christoph Lauter, Marc Mezzarobba
// 
// Contact : christoph.lauter@lip6.fr, marc@mezzarobba.net
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// 

#include <stdio.h>
#include <stdint.h>

/* Get our constants and types */
#include "comparison.h"

#include <math.h>

/* Get the helper functions */
#include "comparison-helper.h"


int main(int argc, char **argv) {
  _binary64 x;
  _Decimal64 y;
  int E, F, neg2, neg10;
  uint64_t m, n;
  int res;
  
  if (argc < 6) return -1;

  neg2 = (argv[1][0] == '-');
  E = strtol(argv[2], NULL, 10);
  m = myatoull(argv[3]);
  neg10 = (argv[4][0] == '-');
  F = strtol(argv[5], NULL, 10);
  n = myatoull(argv[6]);

  x = composeBinary(neg2, E, m);
  y = composeDecimal(neg10, F, n);

  printf("Compare x = 0x%016llx ~ %1.50e with y = 0x%016llxz ~ %1.50e\n",*((unsigned long long int *) &x),x,*((unsigned long long int *) &y),(double)y);

  res = compareSignalingLessEqualBinary64Decimal64(x, y);

  printf("Comparison result: x <= y == %s\n", (res ? "true" : "false"));
  
  return 0;
}


